@@ -5,7 +5,7 @@ test_that("get_layer works", {
   folder <-
     stringr::str_replace_all(paste(folder, "/", ""), " ", "")
   ua <- uscb_acs_5ye(folder = folder)
-  sa <- ua %>% get_statistical_areas()
+  sa <- ua |> get_statistical_areas()
   # sa[6]
   # [1] "New England City and Town Area Division"
   ul <-
@@ -16,10 +16,10 @@ test_that("get_layer works", {
       year = 2015
     )
 
-  layers <- ul %>% get_layer_names()
+  layers <- ul |> get_layer_names()
   # layers[3]
   # [1] "X02_RACE"
-  ul <- ul %>% get_layer(layers[3])
+  ul <- ul |> get_layer(layers[3])
 
   expect_equal(ncol(ul$layer), 433)
   expect_equal(nrow(ul$layer), 10)
