@@ -5,7 +5,7 @@ test_that("get_layer_names works", {
   folder <-
     stringr::str_replace_all(paste(folder, "/", ""), " ", "")
   ua <- uscb_acs_5ye(folder = folder)
-  sa <- ua %>% get_statistical_areas()
+  sa <- ua |> get_statistical_areas()
   # sa[6]
   # [1] "New England City and Town Area Division"
   ul <-
@@ -16,7 +16,7 @@ test_that("get_layer_names works", {
       year = 2015
     )
 
-  layers <- ul %>% get_layer_names()
+  layers <- ul |> get_layer_names()
   expect_equal(
     layers,
     c("X00_COUNTS", "X01_AGE_AND_SEX", "X02_RACE")
